Управлять радиостанцией можно с помощью клиента для протокола XMPP (Jabber). 
Отправляя команды роботу, представляющему станцию, можно голосовать за музыку,
менять текущий плейлист, следить за работой системы и взаимодействовать со
внешним миром.

Робота можно завести в комнату, в которую он будет сообщать о смене программы.
